@@ -119,6 +119,10 @@ test_that("math for indirect: mediation", {
     expect_equal(outm1plus3$indirect, outm$indirect + outm3$indirect)
     expect_equal(outm1m2m3$indirect, outm$indirect + outm2$indirect + outm3$indirect)
     expect_equal(out123pm$indirect, outm$indirect + outm2$indirect - outm3$indirect)
+    expect_equal(outm1plus2$indirect_raw, outm$indirect_raw + outm2$indirect_raw)
+    expect_equal(outm1plus3$indirect_raw, outm$indirect_raw + outm3$indirect_raw)
+    expect_equal(outm1m2m3$indirect_raw, outm$indirect_raw + outm2$indirect_raw + outm3$indirect_raw)
+    expect_equal(out123pm$indirect_raw, outm$indirect_raw + outm2$indirect_raw - outm3$indirect_raw)
     expect_error(outm + outm4)
     expect_error(outm + outm5)
     expect_equal(outm1plus2boot$indirect, outm_boot$indirect + outm2_boot$indirect)
@@ -127,6 +131,12 @@ test_that("math for indirect: mediation", {
     expect_equal(out1m1m2m3boot2$indirect, outm_boot$indirect + outm2_boot$indirect + outm3_boot$indirect)
     expect_equal(outm1minus2boot$indirect, outm_boot$indirect - outm2_boot$indirect)
     expect_equal(outm1minus3boot$indirect, outm_boot$indirect - outm3_boot$indirect)
+    expect_equal(outm1plus2boot$indirect_raw, outm_boot$indirect_raw + outm2_boot$indirect_raw)
+    expect_equal(outm1plus3boot$indirect_raw, outm_boot$indirect_raw + outm3_boot$indirect_raw)
+    expect_equal(outm1m2m3boot$indirect_raw, outm1plus2boot$indirect_raw + outm3_boot$indirect_raw)
+    expect_equal(out1m1m2m3boot2$indirect_raw, outm_boot$indirect_raw + outm2_boot$indirect_raw + outm3_boot$indirect_raw)
+    expect_equal(outm1minus2boot$indirect_raw, outm_boot$indirect_raw - outm2_boot$indirect_raw)
+    expect_equal(outm1minus3boot$indirect_raw, outm_boot$indirect_raw - outm3_boot$indirect_raw)
     expect_error(outm_boot + outm_boot)
     expect_equal(coef(outm1minus2), outm1minus2$indirect, ignore_attr = TRUE)
     expect_equal(coef(outm1plus3), outm1plus3$indirect, ignore_attr = TRUE)
